What if home for you?

Werever it is, you have to keep it at least somewhat clean!
But dirty won't stop comming.

In this "join equal things so they vanish" variant,
you have to actually _swipe_ things up with a broom.
Hold space to use your broom, arrow keys to just
move around. When like-dirty is together, it will
go away!

# Installing

it is instalable in any system where Python 3.7 runs - just
make sure you have "pip" working for your Python

PIP installing this file should automatically install the Pygame and Numpy
requiremnts - otherwise, just uncompress the source and
"pip install pygame numpy"

When things are in place, python3 -m homekeeper should drop you straight
into the game.

The source code and future development of the game are at
https://github.com/jsbueno/homekeeper


To install Python 3.7: https://python.org
To install Python's pip for Windows: https://www.liquidweb.com/kb/install-pip-windows/
(Or preferably, create a virtualenv with python -m venv)

To install pygame and numpy: "pip install pygame numpy"
